local Tunnel = module("vrp", "lib/Tunnel")
local Proxy = module("vrp", "lib/Proxy")

vRP = Proxy.getInterface("vRP")
vRPclient = Tunnel.getInterface("vRP", "vd_dailyreward")

-- Cum functioneaza?:
-- Este o verificare care se executa o data la un timp daca ora este 'hourWhenToReset' atunci le va seta la toti sa poata sa dea /gift iar

local Money = { -- Aici schimbi cat vrei sa castige
    min_money = 500000, -- Suma cea mai mica de bani pe care vrei sa o primeasca
    max_money = 5000000, -- Suma cea mai mare de bani pe care vrei sa o primeasca

    timeToWait = 43200000, -- 12 hours (12 * 60 * 60 * 1000 ms)
    dbCheckInterval = 10000, -- Check database every 10 seconds
}

local playerData = {}
local nextResetTime = 0

-- Function to format money with commas
local function formatMoney(amount)
    local formatted = tostring(amount)
    local k
    while true do
        formatted, k = string.gsub(formatted, "^(-?%d+)(%d%d%d)", '%1,%2')
        if k == 0 then break end
    end
    return formatted
end

-- Function to update player's reward status
local function updatePlayerRewardStatus(source, usrId)
    if not source or not usrId then return end
    
    exports.oxmysql:query("SELECT gift FROM vd_daily WHERE playerId=@usrId", {usrId = usrId}, function(i)
        if i and #i > 0 then
            local newGiftStatus = i[1].gift == 0
            local currentStatus = playerData[usrId] and playerData[usrId].gift == 0

            -- Only update if the status has changed
            if currentStatus ~= newGiftStatus then
                playerData[usrId] = {}
                playerData[usrId].gift = i[1].gift
                TriggerClientEvent("vd:UpdateRewardStatus", source, newGiftStatus)
            end
        end
    end)
end

-- Function to get next reset time from database
local function getNextResetTime()
    exports.oxmysql:query("SELECT next_reset FROM vd_daily_settings LIMIT 1", {}, function(result)
        if result and #result > 0 then
            nextResetTime = result[1].next_reset
        else
            -- If no settings exist, create them with current time + 12 hours
            nextResetTime = os.time() + (Money.timeToWait / 1000)
            exports.oxmysql:query("INSERT INTO vd_daily_settings (next_reset) VALUES (@nextReset)", {nextReset = nextResetTime})
        end
    end)
end

-- Function to update next reset time
local function updateNextResetTime()
    nextResetTime = os.time() + (Money.timeToWait / 1000)
    exports.oxmysql:query("UPDATE vd_daily_settings SET next_reset = @nextReset", {nextReset = nextResetTime})
end

-- Initialize next reset time when server starts
Citizen.CreateThread(function()
    Wait(1000) -- Wait for database to be ready
    getNextResetTime()
end)

RegisterCommand("reward", function(src)
    local usrId = vRP.getUserId({src})

    exports.oxmysql:query("SELECT gift FROM vd_daily WHERE playerId=@usrId", {usrId = usrId}, function(i)
        if i and #i > 0 then
            if i[1].gift == 0 then 
                TriggerClientEvent("vd:ShowPlayerUi", src) 
                playerData[usrId] = {} 
                playerData[usrId].gift = i[1].gift
                TriggerClientEvent("vd:UpdateRewardStatus", src, true)
            else
                vRPclient.notify(src, {"Succes: Ti-ai luat reward-ul pe azi"})
                TriggerClientEvent("vd:UpdateRewardStatus", src, false)
            end
        else
            exports.oxmysql:query("INSERT INTO vd_daily (playerId) VALUES (@playerId)", {playerId = usrId})
            TriggerClientEvent("vd:ShowPlayerUi", src)
            playerData[usrId] = {}
            playerData[usrId].gift = 0
            TriggerClientEvent("vd:UpdateRewardStatus", src, true)
        end
    end)
end)

RegisterServerEvent("vd:CheckRewardStatus", function()
    local src = source
    local usrId = vRP.getUserId({src})
    
    if not usrId then return end
    updatePlayerRewardStatus(src, usrId)
end)

RegisterServerEvent("vd:GivePlayerReward", function()
    local source = source
    local usrId = vRP.getUserId({source})
    if playerData[usrId] and playerData[usrId].gift == 0 then
        local rewardInMoney = math.random(Money.min_money, Money.max_money)
        local playerName = GetPlayerName(source)
        vRP.giveMoney({usrId,rewardInMoney})
        
        -- Broadcast pentru toți jucătorii cu mesaj combinat
        local message = "^5[Daily Rewards] ^7"..playerName.." ^2a colectat ^7"..formatMoney(rewardInMoney).." RON ^2din daily reward!"
        
        local players = GetPlayers()
        for _, playerId in ipairs(players) do
            TriggerClientEvent('chatMessage', playerId, "", {255, 255, 255}, message)
        end
        
        exports.oxmysql:query("UPDATE vd_daily SET gift = 1 WHERE playerId = @playerId", {playerId = usrId})
        playerData[usrId].gift = 1
        TriggerClientEvent("vd:UpdateRewardStatus", source, false)
    else
        vRPclient.notify(source,{"^1Ai colectat deja recompensa zilnică!"})
    end
end)

-- Function to update all online players
local function updateAllOnlinePlayers()
    local players = GetPlayers()
    for _, playerId in ipairs(players) do
        local usrId = vRP.getUserId({playerId})
        if usrId then
            updatePlayerRewardStatus(playerId, usrId)
        end
    end
end

-- Check for reset every 30 seconds
Citizen.CreateThread(function()
    while true do
        Wait(30000) -- Check every 30 seconds
        local currentTime = os.time()
        
        if currentTime >= nextResetTime then
            print("^2[Daily Rewards] Attempting to reset rewards...")
            exports.oxmysql:query("UPDATE vd_daily SET gift = 0", {}, function(affected)
                if affected then
                    print("^2[Daily Rewards] Successfully reset rewards for all players!")
                    updateNextResetTime() -- Update next reset time
                else
                    print("^1[Daily Rewards] Failed to reset rewards!")
                end
            end)
            Wait(1000)
            updateAllOnlinePlayers()
            print("^2[Daily Rewards] Finished updating all online players")
        end
    end
end)

-- Frequent database check thread
Citizen.CreateThread(function()
    while true do
        Wait(Money.dbCheckInterval)
        updateAllOnlinePlayers()
    end
end)